summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--validate/gst/validate/gst-validate-scenario.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/validate/gst/validate/gst-validate-scenario.c b/validate/gst/validate/gst-validate-scenario.c
index 8886ce1..1236f5b 100644
--- a/validate/gst/validate/gst-validate-scenario.c
+++ b/validate/gst/validate/gst-validate-scenario.c
@@ -31,8 +31,8 @@
* Possible configurations (see #GST_VALIDATE_CONFIG):
* * scenario-action-execution-interval: Sets the interval in
* milliseconds (1/1000ths of a second), between which actions
* will be executed, setting it to 0 means "execute in idle"
* (which is the default).
*/
#ifdef HAVE_CONFIG_H
@@ -2513,6 +2513,7 @@ gst_validate_scenario_init (GstValidateScenario * scenario)
priv->seek_pos_tol = DEFAULT_SEEK_TOLERANCE;
priv->segment_start = 0;
priv->segment_stop = GST_CLOCK_TIME_NONE;
+ priv->action_execution_interval = 10;
g_mutex_init (&priv->lock);
}
@@ -31,8 +31,8 @@
* * scenario-action-execution-interval: Sets the interval in
* milliseconds (1/1000ths of a second), between which actions
- * will be executed, setting it to 0 means "execute in idle"
- * (which is the default).
+ * will be executed, setting it to 0 means "execute in idle".
+ * The default value is 10ms.
*/
#ifdef HAVE_CONFIG_H